@@ -4,7 +4,7 @@
    Copyright 1999 Dave Cinege
    Portions copyright (C) 1990-1996 Free Software Foundation, Inc.
 
-   Licensed under GPL v2 or later, see file LICENSE in this tarball for details.
+   Licensed under GPLv2 or later, see file LICENSE in this source tree.
 */
 
 /* Usage: printf format [argument...]
@@ -66,7 +66,7 @@ static int multiconvert(const char *arg, void *result, converter convert)
 	errno = 0;
 	convert(arg, result);
 	if (errno) {
-		bb_error_msg("%s: invalid number", arg);
+		bb_error_msg("invalid number '%s'", arg);
 		return 1;
 	}
 	return 0;
@@ -122,16 +122,14 @@ static double my_xstrtod(const char *arg)
 	return result;
 }
 
-static void print_esc_string(char *str)
+static void print_esc_string(const char *str)
 {
-	while (*str) {
-		if (*str == '\\') {
-			str++;
-			bb_putchar(bb_process_escape_sequence((const char **)&str));
-		} else {
-			bb_putchar(*str);
-			str++;
-		}
+	char c;
+	while ((c = *str) != '\0') {
+		str++;
+		if (c == '\\')
+			c = bb_process_escape_sequence(&str);
+		putchar(c);
 	}
 }
 
@@ -230,7 +228,7 @@ static int get_width_prec(const char *str)
 {
 	int v = bb_strtoi(str, NULL, 10);
 	if (errno) {
-		bb_error_msg("%s: invalid number", str);
+		bb_error_msg("invalid number '%s'", str);
 		v = 0;
 	}
 	return v;
@@ -344,7 +342,7 @@ static char **print_formatted(char *f, char **argv, int *conv_err)
 			f--;
 			break;
 		default:
-			bb_putchar(*f);
+			putchar(*f);
 		}
 	}
 
