@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2008 by Vladimir Dronnikov <dronnikov@gmail.com>
  *
- * Licensed under GPLv2, see file LICENSE in this tarball for details.
+ * Licensed under GPLv2, see file LICENSE in this source tree.
  */
 
 /*
@@ -34,8 +34,8 @@ static const char mask_names[] ALIGN1 =
 	"a"	// 0x00000001	File was accessed
 	"c"	// 0x00000002	File was modified
 	"e"	// 0x00000004	Metadata changed
-	"w"	// 0x00000008	Writtable file was closed
-	"0"	// 0x00000010	Unwrittable file closed
+	"w"	// 0x00000008	Writable file was closed
+	"0"	// 0x00000010	Unwritable file closed
 	"r"	// 0x00000020	File was opened
 	"m"	// 0x00000040	File was moved from X
 	"y"	// 0x00000080	File was moved to Y
@@ -155,7 +155,7 @@ int inotifyd_main(int argc, char **argv)
 				args[1] = events;
 				args[2] = watches[ie->wd];
 				args[3] = ie->len ? ie->name : NULL;
-				wait4pid(xspawn((char **)args));
+				spawn_and_wait((char **)args);
 				// we are done if all files got final x event
 				if (ie->mask & 0x8000) {
 					if (--argc <= 0)
