@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2006 Bernhard Reutner-Fischer
  *
- * Licensed under the GPL v2 or later, see the file LICENSE in this tarball.
+ * Licensed under GPLv2 or later, see file LICENSE in this source tree.
  *
  */
 
@@ -14,12 +14,8 @@
 #include <linux/raid/md_u.h>
 
 int raidautorun_main(int argc, char **argv) MAIN_EXTERNALLY_VISIBLE;
-int raidautorun_main(int argc, char **argv)
+int raidautorun_main(int argc UNUSED_PARAM, char **argv)
 {
-	if (argc != 2)
-		bb_show_usage();
-
-	xioctl(xopen(argv[1], O_RDONLY), RAID_AUTORUN, NULL);
-
+	xioctl(xopen(single_argv(argv), O_RDONLY), RAID_AUTORUN, NULL);
 	return EXIT_SUCCESS;
 }
